summaryrefslogtreecommitdiffstats
path: root/WebKit/android/WebCoreSupport/WebRequestContext.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'WebKit/android/WebCoreSupport/WebRequestContext.cpp')
-rw-r--r--WebKit/android/WebCoreSupport/WebRequestContext.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/WebKit/android/WebCoreSupport/WebRequestContext.cpp b/WebKit/android/WebCoreSupport/WebRequestContext.cpp
index 99e44ec..e108e2a 100644
--- a/WebKit/android/WebCoreSupport/WebRequestContext.cpp
+++ b/WebKit/android/WebCoreSupport/WebRequestContext.cpp
@@ -52,6 +52,7 @@ WebRequestContext::WebRequestContext(bool isPrivateBrowsing)
if (m_isPrivateBrowsing) {
// Delete the old files if this is the first private browsing instance
// They are probably leftovers from a power cycle
+ // We do not need to clear the cache as it is in memory only for private browsing
if (!numPrivateBrowsingInstances)
WebCookieJar::cleanup(true);
numPrivateBrowsingInstances++;
@@ -74,9 +75,11 @@ WebRequestContext::~WebRequestContext()
if (m_isPrivateBrowsing) {
numPrivateBrowsingInstances--;
- // This is the last private browsing context, delete the cookies
- if (!numPrivateBrowsingInstances)
+ // This is the last private browsing context, delete the cookies and cache
+ if (!numPrivateBrowsingInstances) {
WebCookieJar::cleanup(true);
+ WebCache::cleanup(true);
+ }
}
}